@@ -36,6 +36,7 @@ class loeb:
             listOfDfs = []
             counter = 0
             df = pd.DataFrame.from_records(df_dict)
+            total_entrys = len(df)
             for i in df.itertuples():
                 img = i.img_link
                 info = i.info_link
@@ -85,7 +86,9 @@ class loeb:
 
                 counter += 1
 
+
                 self.list_of_dfs.extend(listOfDfs)
+                print("Collected Data for ", counter, "out of", total_entrys, "images")
 
         self.list_of_dfs = []
         self.image_cache = []
